@@ -32,7 +32,7 @@ has config =>
 	required => 0,
 );
 
-our $VERSION = '2.26';
+our $VERSION = '2.27';
 
 # ------------------------------------------------
 
@@ -115,9 +115,9 @@ sub generate_demo_index
 	);
 	my($file_name) = File::Spec -> catfile($html_dir_name, 'index.html');
 
-	open(OUT, '>', $file_name);
-	print OUT $index;
-	close OUT;
+	open(my $fh, '>', $file_name);
+	print $fh $index;
+	close $fh;
 
 	print "Wrote $file_name\n";
 
